<?php

namespace Barn2\Plugin\WC_Restaurant_Ordering\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Step;
use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Util;
use Barn2\Plugin\WC_Restaurant_Ordering\Settings;
use Barn2\WRO_Lib\WooCommerce\Admin\Settings_Util;

class Order_Form extends Step {

	private $checkboxes = [
		'wro_show_navigation',
		'wro_show_category_titles',
		'wro_show_category_descriptions',
		'wro_show_product_image',
		'wro_show_product_description',
	];

	/**
	 * Configure the step.
	 */
	public function __construct() {
		$this->set_id( 'order-form' );
		$this->set_name( esc_html__( 'Order form', 'woocommerce-restaurant-ordering' ) );
		$this->set_title( esc_html__( 'Order form content', 'woocommerce-restaurant-ordering' ) );
		$this->set_description( esc_html__( 'Now, choose the information that will appear in your food order forms.', 'woocommerce-restaurant-ordering' ) );
	}

	/**
	 * Setup fields.
	 *
	 * @return array
	 */
	public function setup_fields() {

		$fields['my_heading'] = [
			'type'  => 'heading',
			'label' => __( 'Order form', 'woocommerce-restaurant-ordering' ),
			'style' => [
				'paddingTop'   => '2rem',
				'marginBottom' => '0'
			]
		];

		$plucked = Util::pluck_wc_settings(
			Settings::get_order_form_settings(),
			[
				'wro_show_navigation',
				'wro_show_category_titles',
				'wro_show_category_descriptions',
				'wro_show_product_image',
				'wro_show_product_description',
				'wro_menu_columns',
			]
		);

		$fields = array_merge( $fields, $plucked );

		$fields['wro_show_navigation']['border']      = false;
		$fields['wro_show_navigation']['description'] = false;

		$fields['wro_show_category_titles']['border']      = false;
		$fields['wro_show_category_titles']['description'] = false;

		$fields['wro_show_category_descriptions']['border']      = false;
		$fields['wro_show_category_descriptions']['description'] = false;

		$fields['wro_show_product_image']['border']      = false;
		$fields['wro_show_product_image']['description'] = false;

		$fields['wro_show_product_description']['type']        = 'checkbox';
		$fields['wro_show_product_description']['border']      = false;
		$fields['wro_show_product_description']['label']       = $fields['wro_show_product_description']['description'];
		$fields['wro_show_product_description']['description'] = false;

		$fields['wro_show_product_description']['value'] = Settings_Util::checkbox_setting_to_bool( $fields['wro_show_product_description']['value'] );

		$fields['wro_menu_columns']['value'] = absint( $fields['wro_menu_columns']['value'] );

		return $fields;
	}

	/**
	 * Handle submission.
	 *
	 * @return void
	 */
	public function submit() {
		check_ajax_referer( 'barn2_setup_wizard_nonce', 'nonce' );

		if ( ! current_user_can( 'manage_options' ) ) {
			$this->send_error( esc_html__( 'You are not authorized.', 'woocommerce-restaurant-ordering' ) );
		}

		$values = $this->get_submitted_values();

		foreach ( $values as $option_key => $option_value ) {
			if ( in_array( $option_key, $this->checkboxes, true ) ) {
				if ( $option_value === 'false' ) {
					$option_value = 'no';
				} elseif ( $option_value === 'true' ) {
					$option_value = 'yes';
				}
			}

			update_option( $option_key, $option_value );
		}

		wp_send_json_success();
	}
}
