<?php

namespace Barn2\Plugin\WC_Restaurant_Ordering\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Restaurant_Ordering\Admin\Wizard\Setup_Wizard;
use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Step;
use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Util;
use Barn2\Plugin\WC_Restaurant_Ordering\Settings;

class Pages extends Step {
	/**
	 * Configure the step.
	 */
	public function __construct() {
		$this->set_id( 'pages' );
		$this->set_name( esc_html__( 'Pages', 'woocommerce-restaurant-ordering' ) );
		$this->set_title( esc_html__( 'Pages', 'woocommerce-restaurant-ordering' ) );
		$this->set_description( esc_html__( 'First, set up your main restaurant ordering pages. You can also create food order forms manually by adding the [restaurant_ordering] shortcode to any page', 'woocommerce-restaurant-ordering' ) );
	}

	/**
	 * Setup fields.
	 *
	 * @return array
	 */
	public function setup_fields() {
		$fields = Util::pluck_wc_settings(
			Settings::get_general_settings( $this->get_plugin() ),
			[ 'wro_menu_page', 'wro_categories' ]
		);

		if ( ! empty( $fields['wro_menu_page']['value'] ) && get_post_status( $fields['wro_menu_page']['value'] ) ) {
			$fields['wro_menu_page']['value'] = absint( $fields['wro_menu_page']['value'] );
		}

		$fields['wro_categories']['type']     = 'select';
		$fields['wro_categories']['multiple'] = true;

		$fields['wro_categories']['options'] = Setup_Wizard::parse_multiselct_options( $fields['wro_categories']['options'] );

		if ( ! empty( $fields['wro_categories']['value'] ) ) {
			$fields['wro_categories']['value'] = array_map( 'absint', $fields['wro_categories']['value'] );
		} else {
			$fields['wro_categories']['value'] = [];
		}

		return $fields;
	}

	/**
	 * Handle submission.
	 *
	 * @return void
	 */
	public function submit() {
		check_ajax_referer( 'barn2_setup_wizard_nonce', 'nonce' );

		if ( ! current_user_can( 'manage_options' ) ) {
			$this->send_error( esc_html__( 'You are not authorized.', 'woocommerce-restaurant-ordering' ) );
		}

		$values = $this->get_submitted_values();

		if ( ! empty( $values['wro_menu_page'] ) ) {
			update_option( 'wro_menu_page', $values['wro_menu_page'] );
			Settings::add_shortcode_to_page( $values['wro_menu_page'] );
		}

		if ( ! empty( $values['wro_categories'] ) && is_array( $values['wro_categories'] ) ) {
			$categories = [];

			foreach ( $values['wro_categories'] as $category ) {
				$categories[] = $category['key'];
			}

			update_option( 'wro_categories', $categories );
		}

		wp_send_json_success();
	}

}
