<?php

namespace Barn2\Plugin\WC_Restaurant_Ordering\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Step;
use Barn2\Plugin\WC_Restaurant_Ordering\Dependencies\Barn2\Setup_Wizard\Util;
use Barn2\Plugin\WC_Restaurant_Ordering\Settings;

class Restaurant_Details extends Step {
	/**
	 * Configure the step.
	 */
	public function __construct() {
		$this->set_id( 'restaurant-details' );
		$this->set_name( esc_html__( 'Restaurant details', 'woocommerce-restaurant-ordering' ) );
		$this->set_title( esc_html__( 'Restaurant details', 'woocommerce-restaurant-ordering' ) );
		$this->set_description( esc_html__( 'If you like, then you can display restaurant information above the food order form.', 'woocommerce-restaurant-ordering' ) );
	}

	/**
	 * Setup fields.
	 *
	 * @return array
	 */
	public function setup_fields() {
		$fields = Util::pluck_wc_settings(
			Settings::get_restaurant_info_settings(),
			[ 'wro_restaurant_name', 'wro_restaurant_address', 'wro_delivery_notice' ]
		);

		return $fields;
	}

	/**
	 * Handle submission.
	 *
	 * @return void
	 */
	public function submit() {
		check_ajax_referer( 'barn2_setup_wizard_nonce', 'nonce' );

		if ( ! current_user_can( 'manage_options' ) ) {
			$this->send_error( esc_html__( 'You are not authorized.', 'woocommerce-restaurant-ordering' ) );
		}

		$values = $this->get_submitted_values();

		$max_length = Settings::get_restaurant_info_max_length();

		if ( is_array( $values ) && ! empty( $values ) ) {
			foreach ( $values as $key => $value ) {
				if ( strlen( $value ) > $max_length ) {
					$field = $this->get_fields()[ $key ];
					$label = $field['label'];
					$this->send_error( sprintf( __( '"%1$s" should not exceed the max length of %2$s characters.', 'woocommerce-restaurant-ordering' ), $label, $max_length ) );
				}

				update_option( $key, $value );
			}
		}
	}
}
