<?php

namespace Barn2\Plugin\WC_Restaurant_Ordering\Integration;

use Barn2\Plugin\WC_Product_Table\Table_Shortcode;
use Barn2\WRO_Lib\Registerable;
use Barn2\WRO_Lib\Service;
use Barn2\WRO_Lib\Util;

/**
 * Handles the WooCommerce Product Table integration.
 *
 * @package   Barn2\woocommerce-restaurant-ordering
 * @author    Barn2 Plugins <support@barn2.com>
 * @license   GPL-3.0
 * @copyright Barn2 Media Ltd
 */
class Product_Table implements Service, Registerable {

	/**
	 * Register the integrations for Product Addons.
	 */
	public function register() {
		if ( ! Util::is_product_table_active() ) {
			return;
		}

		// Remove product table shortcodes from menu product description and modal description. The add to cart feature
		// of the product table conflict with the cart form in the restaurant modal.
		add_filter( 'wc_restaurant_ordering_modal_description_before_formatting', [ $this, 'remove_tables_from_description' ] );
		add_filter( 'wc_restaurant_ordering_product_description_before_formatting', [ $this, 'remove_tables_from_description' ] );
	}

	/**
	 * Remove [product_table] shortcode from modal description content. The add to cart feature of the table will
	 * conflict with the cart form in the restaurant modal.
	 *
	 * @param string $description The modal description
	 * @return string The filtered description
	 */
	public function remove_tables_from_description( string $description ): string {
		return (string) preg_replace( sprintf( '#\[%s.*?\]#', Table_Shortcode::SHORTCODE ), '', $description );
	}

}